# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1AwsDataConnection(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'destination': 'str',
        'region': 'str',
        'secret_arn_name': 'str',
        'secret_arn_value': 'str',
        'secret_id_access_key_id': 'str',
        'secret_id_secret_access_key': 'str',
        'secret_value_access_key_id': 'str',
        'secret_value_secret_access_key': 'str',
        'source': 'str'
    }

    attribute_map = {
        'destination': 'destination',
        'region': 'region',
        'secret_arn_name': 'secretArnName',
        'secret_arn_value': 'secretArnValue',
        'secret_id_access_key_id': 'secretIdAccessKeyId',
        'secret_id_secret_access_key': 'secretIdSecretAccessKey',
        'secret_value_access_key_id': 'secretValueAccessKeyId',
        'secret_value_secret_access_key': 'secretValueSecretAccessKey',
        'source': 'source'
    }

    def __init__(self, destination: 'str' =None, region: 'str' =None, secret_arn_name: 'str' =None, secret_arn_value: 'str' =None, secret_id_access_key_id: 'str' =None, secret_id_secret_access_key: 'str' =None, secret_value_access_key_id: 'str' =None, secret_value_secret_access_key: 'str' =None, source: 'str' =None):  # noqa: E501
        """V1AwsDataConnection - a model defined in Swagger"""  # noqa: E501
        self._destination = None
        self._region = None
        self._secret_arn_name = None
        self._secret_arn_value = None
        self._secret_id_access_key_id = None
        self._secret_id_secret_access_key = None
        self._secret_value_access_key_id = None
        self._secret_value_secret_access_key = None
        self._source = None
        self.discriminator = None
        if destination is not None:
            self.destination = destination
        if region is not None:
            self.region = region
        if secret_arn_name is not None:
            self.secret_arn_name = secret_arn_name
        if secret_arn_value is not None:
            self.secret_arn_value = secret_arn_value
        if secret_id_access_key_id is not None:
            self.secret_id_access_key_id = secret_id_access_key_id
        if secret_id_secret_access_key is not None:
            self.secret_id_secret_access_key = secret_id_secret_access_key
        if secret_value_access_key_id is not None:
            self.secret_value_access_key_id = secret_value_access_key_id
        if secret_value_secret_access_key is not None:
            self.secret_value_secret_access_key = secret_value_secret_access_key
        if source is not None:
            self.source = source

    @property
    def destination(self) -> 'str':
        """Gets the destination of this V1AwsDataConnection.  # noqa: E501


        :return: The destination of this V1AwsDataConnection.  # noqa: E501
        :rtype: str
        """
        return self._destination

    @destination.setter
    def destination(self, destination: 'str'):
        """Sets the destination of this V1AwsDataConnection.


        :param destination: The destination of this V1AwsDataConnection.  # noqa: E501
        :type: str
        """

        self._destination = destination

    @property
    def region(self) -> 'str':
        """Gets the region of this V1AwsDataConnection.  # noqa: E501


        :return: The region of this V1AwsDataConnection.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region: 'str'):
        """Sets the region of this V1AwsDataConnection.


        :param region: The region of this V1AwsDataConnection.  # noqa: E501
        :type: str
        """

        self._region = region

    @property
    def secret_arn_name(self) -> 'str':
        """Gets the secret_arn_name of this V1AwsDataConnection.  # noqa: E501


        :return: The secret_arn_name of this V1AwsDataConnection.  # noqa: E501
        :rtype: str
        """
        return self._secret_arn_name

    @secret_arn_name.setter
    def secret_arn_name(self, secret_arn_name: 'str'):
        """Sets the secret_arn_name of this V1AwsDataConnection.


        :param secret_arn_name: The secret_arn_name of this V1AwsDataConnection.  # noqa: E501
        :type: str
        """

        self._secret_arn_name = secret_arn_name

    @property
    def secret_arn_value(self) -> 'str':
        """Gets the secret_arn_value of this V1AwsDataConnection.  # noqa: E501


        :return: The secret_arn_value of this V1AwsDataConnection.  # noqa: E501
        :rtype: str
        """
        return self._secret_arn_value

    @secret_arn_value.setter
    def secret_arn_value(self, secret_arn_value: 'str'):
        """Sets the secret_arn_value of this V1AwsDataConnection.


        :param secret_arn_value: The secret_arn_value of this V1AwsDataConnection.  # noqa: E501
        :type: str
        """

        self._secret_arn_value = secret_arn_value

    @property
    def secret_id_access_key_id(self) -> 'str':
        """Gets the secret_id_access_key_id of this V1AwsDataConnection.  # noqa: E501


        :return: The secret_id_access_key_id of this V1AwsDataConnection.  # noqa: E501
        :rtype: str
        """
        return self._secret_id_access_key_id

    @secret_id_access_key_id.setter
    def secret_id_access_key_id(self, secret_id_access_key_id: 'str'):
        """Sets the secret_id_access_key_id of this V1AwsDataConnection.


        :param secret_id_access_key_id: The secret_id_access_key_id of this V1AwsDataConnection.  # noqa: E501
        :type: str
        """

        self._secret_id_access_key_id = secret_id_access_key_id

    @property
    def secret_id_secret_access_key(self) -> 'str':
        """Gets the secret_id_secret_access_key of this V1AwsDataConnection.  # noqa: E501


        :return: The secret_id_secret_access_key of this V1AwsDataConnection.  # noqa: E501
        :rtype: str
        """
        return self._secret_id_secret_access_key

    @secret_id_secret_access_key.setter
    def secret_id_secret_access_key(self, secret_id_secret_access_key: 'str'):
        """Sets the secret_id_secret_access_key of this V1AwsDataConnection.


        :param secret_id_secret_access_key: The secret_id_secret_access_key of this V1AwsDataConnection.  # noqa: E501
        :type: str
        """

        self._secret_id_secret_access_key = secret_id_secret_access_key

    @property
    def secret_value_access_key_id(self) -> 'str':
        """Gets the secret_value_access_key_id of this V1AwsDataConnection.  # noqa: E501


        :return: The secret_value_access_key_id of this V1AwsDataConnection.  # noqa: E501
        :rtype: str
        """
        return self._secret_value_access_key_id

    @secret_value_access_key_id.setter
    def secret_value_access_key_id(self, secret_value_access_key_id: 'str'):
        """Sets the secret_value_access_key_id of this V1AwsDataConnection.


        :param secret_value_access_key_id: The secret_value_access_key_id of this V1AwsDataConnection.  # noqa: E501
        :type: str
        """

        self._secret_value_access_key_id = secret_value_access_key_id

    @property
    def secret_value_secret_access_key(self) -> 'str':
        """Gets the secret_value_secret_access_key of this V1AwsDataConnection.  # noqa: E501


        :return: The secret_value_secret_access_key of this V1AwsDataConnection.  # noqa: E501
        :rtype: str
        """
        return self._secret_value_secret_access_key

    @secret_value_secret_access_key.setter
    def secret_value_secret_access_key(self, secret_value_secret_access_key: 'str'):
        """Sets the secret_value_secret_access_key of this V1AwsDataConnection.


        :param secret_value_secret_access_key: The secret_value_secret_access_key of this V1AwsDataConnection.  # noqa: E501
        :type: str
        """

        self._secret_value_secret_access_key = secret_value_secret_access_key

    @property
    def source(self) -> 'str':
        """Gets the source of this V1AwsDataConnection.  # noqa: E501


        :return: The source of this V1AwsDataConnection.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source: 'str'):
        """Sets the source of this V1AwsDataConnection.


        :param source: The source of this V1AwsDataConnection.  # noqa: E501
        :type: str
        """

        self._source = source

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1AwsDataConnection, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1AwsDataConnection') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1AwsDataConnection):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1AwsDataConnection') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



import fnmatch
import logging
import os
from pathlib import Path
from copy import copy
from shutil import copy2, copystat, Error
from typing import List, Callable, Set, Union

from lightning_cloud.env import DOT_IGNORE_FILENAME

logger = logging.getLogger(__name__)


def copytree(src: Union[Path, str],
             dst: Union[Path, str],
             ignore_functions: List[Callable] = None,
             dirs_exist_ok=False,
             dry_run=False) -> List[str]:
    """
    Vendor in from `shutil.copytree` to support ignoring files recursively
    based on `.lightningignore`, like `git` does with `.gitignore`. Also
    removed a few checks from the original copytree related to symlink
    checks. Differences between original and this function are

    1. It supports a list of ignore function instead of a single one in the
        original. We can use this for filtering out files based on nested
        .lightningignore files
    2. It supports a dry run. When enabled, this function will not copy anything but just recursively
        find the source files which are not-ignored and return them. It is useful while calculating
        the hash or checking the size of files
    3. This function returns a list of copied files unlike the original which was returning the
        destination directory

    Recursively copy a directory tree and return the destination directory.

    Parameters
    ----------
    src:
        Source directory path to copy from
    dst:
        Destination directory path to copy to
    ignore_functions:
        List of functions that will be used to filter out files
        and directories. This isn't required to be passed when calling from outside but will be
        autopopulated by the recursive calls in this function itself (Original copytree doesn't have this argument)
    dirs_exist_ok:
        If true, the destination directory will be created if it doesn't exist.
    dry_run:
        If true, this function will not copy anything (this is not present in the original copytree)


    If exception(s) occur, an Error is raised with a list of reasons.
    """
    files_copied = []

    if ignore_functions is None:
        ignore_functions = []

    _ignore_filename_spell_check(src)
    src = Path(src)
    dst = Path(dst)
    if src.joinpath(DOT_IGNORE_FILENAME).exists():
        ignore_fn = get_ignore_function(src)
        # creating new list so we won't modify the original
        ignore_functions = [*ignore_functions, ignore_fn]

    if not dry_run:
        os.makedirs(dst, exist_ok=dirs_exist_ok)

    errors = []

    entries = [dr for dr in src.iterdir()]
    for fn in ignore_functions:
        # ignore function return only the entries that are not ignored
        entries = fn(src, entries)

    for srcentry in entries:
        dstpath = dst / srcentry.name
        try:
            if srcentry.is_dir():
                _files = copytree(src=srcentry,
                                  dst=dstpath,
                                  ignore_functions=ignore_functions,
                                  dirs_exist_ok=dirs_exist_ok,
                                  dry_run=dry_run)
                files_copied.extend(_files)
            else:
                files_copied.append(str(srcentry))
                if not dry_run:
                    # Will raise a SpecialFileError for unsupported file types
                    copy2(srcentry, dstpath)
        # catch the Error from the recursive copytree so that we can
        # continue with other files
        except Error as err:
            errors.extend(err.args[0])
        except OSError as why:
            errors.append((srcentry, dstpath, str(why)))
    try:
        if not dry_run:
            copystat(src, dst)
    except OSError as why:
        # Copying file access times may fail on Windows
        if getattr(why, 'winerror', None) is None:
            errors.append((src, dst, str(why)))
    if errors:
        raise Error(errors)
    return files_copied


def get_ignore_function(src: Path) -> Callable:
    patterns = _read_lightningignore(src / DOT_IGNORE_FILENAME)

    def filter_ignored(current_dir: Path, entries: List[Path]) -> List[Path]:
        relative_dir = current_dir.relative_to(src)
        names = [str(relative_dir / entry.name) for entry in entries]
        ignored_names = []
        for pattern in patterns:
            ignored_names.extend(fnmatch.filter(names, pattern))
        ignored_names_set = set(ignored_names)
        return [
            entry for entry in entries
            if str(relative_dir / entry.name) not in ignored_names_set
        ]

    return filter_ignored


def _read_lightningignore(path: Path) -> Set[str]:
    """
    Reads ignore file and filter and empty lines. This will also remove patterns that start with a `/`.
    That's done to allow `glob` to simulate the behavior done by `git` where it interprets that as a
    root path.

    Parameters
    ----------
    path: Path
        Path to .lightningignore file or equivalent.

    Returns
    -------
    Set[str]
        Set of unique lines.
    """
    raw_lines = [ln.strip() for ln in path.open().readlines()]

    # creates a set that removes empty lines and comments
    lines = {
        ln
        for ln in raw_lines
        if ln != "" and ln is not None and not ln.startswith("#")
    }

    # removes first `/` character for posix and `\\` for windows
    # also converting to path and converting back to string to sanitize the pattern
    return {str(Path(ln.lstrip("/").lstrip("\\"))) for ln in lines}


def _ignore_filename_spell_check(src: Path):
    possible_spelling_mistakes = [
        ".gridignore",
        ".lightingignore",
        ".lightinginore",
        ".lightninginore",
        ".lightninignore",
        ".lightinignore",
    ]
    possible_spelling_mistakes.extend(
        [p.lstrip(".") for p in possible_spelling_mistakes])
    for path in src.iterdir():
        if path.is_file() and path.name in possible_spelling_mistakes:
            logger.warning(
                f"Lightning uses `{DOT_IGNORE_FILENAME}` as the ignore file but found {path.name} at "
                f"{path.parent} instead. If this was a mistake, please rename the file."
            )



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1SlurmNode(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'address': 'str',
        'alloc_cpus': 'int',
        'alloc_memory': 'str',
        'architecture': 'str',
        'cores': 'int',
        'cpus': 'int',
        'free_memory': 'str',
        'hostname': 'str',
        'idle_cpus': 'int',
        'name': 'str',
        'operating_system': 'str',
        'slurmd_version': 'str',
        'state': 'str'
    }

    attribute_map = {
        'address': 'address',
        'alloc_cpus': 'allocCpus',
        'alloc_memory': 'allocMemory',
        'architecture': 'architecture',
        'cores': 'cores',
        'cpus': 'cpus',
        'free_memory': 'freeMemory',
        'hostname': 'hostname',
        'idle_cpus': 'idleCpus',
        'name': 'name',
        'operating_system': 'operatingSystem',
        'slurmd_version': 'slurmdVersion',
        'state': 'state'
    }

    def __init__(self, address: 'str' =None, alloc_cpus: 'int' =None, alloc_memory: 'str' =None, architecture: 'str' =None, cores: 'int' =None, cpus: 'int' =None, free_memory: 'str' =None, hostname: 'str' =None, idle_cpus: 'int' =None, name: 'str' =None, operating_system: 'str' =None, slurmd_version: 'str' =None, state: 'str' =None):  # noqa: E501
        """V1SlurmNode - a model defined in Swagger"""  # noqa: E501
        self._address = None
        self._alloc_cpus = None
        self._alloc_memory = None
        self._architecture = None
        self._cores = None
        self._cpus = None
        self._free_memory = None
        self._hostname = None
        self._idle_cpus = None
        self._name = None
        self._operating_system = None
        self._slurmd_version = None
        self._state = None
        self.discriminator = None
        if address is not None:
            self.address = address
        if alloc_cpus is not None:
            self.alloc_cpus = alloc_cpus
        if alloc_memory is not None:
            self.alloc_memory = alloc_memory
        if architecture is not None:
            self.architecture = architecture
        if cores is not None:
            self.cores = cores
        if cpus is not None:
            self.cpus = cpus
        if free_memory is not None:
            self.free_memory = free_memory
        if hostname is not None:
            self.hostname = hostname
        if idle_cpus is not None:
            self.idle_cpus = idle_cpus
        if name is not None:
            self.name = name
        if operating_system is not None:
            self.operating_system = operating_system
        if slurmd_version is not None:
            self.slurmd_version = slurmd_version
        if state is not None:
            self.state = state

    @property
    def address(self) -> 'str':
        """Gets the address of this V1SlurmNode.  # noqa: E501


        :return: The address of this V1SlurmNode.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address: 'str'):
        """Sets the address of this V1SlurmNode.


        :param address: The address of this V1SlurmNode.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def alloc_cpus(self) -> 'int':
        """Gets the alloc_cpus of this V1SlurmNode.  # noqa: E501


        :return: The alloc_cpus of this V1SlurmNode.  # noqa: E501
        :rtype: int
        """
        return self._alloc_cpus

    @alloc_cpus.setter
    def alloc_cpus(self, alloc_cpus: 'int'):
        """Sets the alloc_cpus of this V1SlurmNode.


        :param alloc_cpus: The alloc_cpus of this V1SlurmNode.  # noqa: E501
        :type: int
        """

        self._alloc_cpus = alloc_cpus

    @property
    def alloc_memory(self) -> 'str':
        """Gets the alloc_memory of this V1SlurmNode.  # noqa: E501


        :return: The alloc_memory of this V1SlurmNode.  # noqa: E501
        :rtype: str
        """
        return self._alloc_memory

    @alloc_memory.setter
    def alloc_memory(self, alloc_memory: 'str'):
        """Sets the alloc_memory of this V1SlurmNode.


        :param alloc_memory: The alloc_memory of this V1SlurmNode.  # noqa: E501
        :type: str
        """

        self._alloc_memory = alloc_memory

    @property
    def architecture(self) -> 'str':
        """Gets the architecture of this V1SlurmNode.  # noqa: E501


        :return: The architecture of this V1SlurmNode.  # noqa: E501
        :rtype: str
        """
        return self._architecture

    @architecture.setter
    def architecture(self, architecture: 'str'):
        """Sets the architecture of this V1SlurmNode.


        :param architecture: The architecture of this V1SlurmNode.  # noqa: E501
        :type: str
        """

        self._architecture = architecture

    @property
    def cores(self) -> 'int':
        """Gets the cores of this V1SlurmNode.  # noqa: E501


        :return: The cores of this V1SlurmNode.  # noqa: E501
        :rtype: int
        """
        return self._cores

    @cores.setter
    def cores(self, cores: 'int'):
        """Sets the cores of this V1SlurmNode.


        :param cores: The cores of this V1SlurmNode.  # noqa: E501
        :type: int
        """

        self._cores = cores

    @property
    def cpus(self) -> 'int':
        """Gets the cpus of this V1SlurmNode.  # noqa: E501


        :return: The cpus of this V1SlurmNode.  # noqa: E501
        :rtype: int
        """
        return self._cpus

    @cpus.setter
    def cpus(self, cpus: 'int'):
        """Sets the cpus of this V1SlurmNode.


        :param cpus: The cpus of this V1SlurmNode.  # noqa: E501
        :type: int
        """

        self._cpus = cpus

    @property
    def free_memory(self) -> 'str':
        """Gets the free_memory of this V1SlurmNode.  # noqa: E501


        :return: The free_memory of this V1SlurmNode.  # noqa: E501
        :rtype: str
        """
        return self._free_memory

    @free_memory.setter
    def free_memory(self, free_memory: 'str'):
        """Sets the free_memory of this V1SlurmNode.


        :param free_memory: The free_memory of this V1SlurmNode.  # noqa: E501
        :type: str
        """

        self._free_memory = free_memory

    @property
    def hostname(self) -> 'str':
        """Gets the hostname of this V1SlurmNode.  # noqa: E501


        :return: The hostname of this V1SlurmNode.  # noqa: E501
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname: 'str'):
        """Sets the hostname of this V1SlurmNode.


        :param hostname: The hostname of this V1SlurmNode.  # noqa: E501
        :type: str
        """

        self._hostname = hostname

    @property
    def idle_cpus(self) -> 'int':
        """Gets the idle_cpus of this V1SlurmNode.  # noqa: E501


        :return: The idle_cpus of this V1SlurmNode.  # noqa: E501
        :rtype: int
        """
        return self._idle_cpus

    @idle_cpus.setter
    def idle_cpus(self, idle_cpus: 'int'):
        """Sets the idle_cpus of this V1SlurmNode.


        :param idle_cpus: The idle_cpus of this V1SlurmNode.  # noqa: E501
        :type: int
        """

        self._idle_cpus = idle_cpus

    @property
    def name(self) -> 'str':
        """Gets the name of this V1SlurmNode.  # noqa: E501


        :return: The name of this V1SlurmNode.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name: 'str'):
        """Sets the name of this V1SlurmNode.


        :param name: The name of this V1SlurmNode.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def operating_system(self) -> 'str':
        """Gets the operating_system of this V1SlurmNode.  # noqa: E501


        :return: The operating_system of this V1SlurmNode.  # noqa: E501
        :rtype: str
        """
        return self._operating_system

    @operating_system.setter
    def operating_system(self, operating_system: 'str'):
        """Sets the operating_system of this V1SlurmNode.


        :param operating_system: The operating_system of this V1SlurmNode.  # noqa: E501
        :type: str
        """

        self._operating_system = operating_system

    @property
    def slurmd_version(self) -> 'str':
        """Gets the slurmd_version of this V1SlurmNode.  # noqa: E501


        :return: The slurmd_version of this V1SlurmNode.  # noqa: E501
        :rtype: str
        """
        return self._slurmd_version

    @slurmd_version.setter
    def slurmd_version(self, slurmd_version: 'str'):
        """Sets the slurmd_version of this V1SlurmNode.


        :param slurmd_version: The slurmd_version of this V1SlurmNode.  # noqa: E501
        :type: str
        """

        self._slurmd_version = slurmd_version

    @property
    def state(self) -> 'str':
        """Gets the state of this V1SlurmNode.  # noqa: E501


        :return: The state of this V1SlurmNode.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state: 'str'):
        """Sets the state of this V1SlurmNode.


        :param state: The state of this V1SlurmNode.  # noqa: E501
        :type: str
        """

        self._state = state

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1SlurmNode, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1SlurmNode') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1SlurmNode):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1SlurmNode') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other
